#!/usr/bin/env python3

"""’Unjag’ a ’jagged’ array passed from Java."""


import zipfile


__all__ = ["unjag"]


def unjag(jagged_array):
    """
    ’Unjag’ a ’jagged’ array passed from Java.

    Java has a concept of ‘jagged’ arrays, i.e., arrays that
    have incomplete/omitted/empty rows. For instance, a jagged
    array might look something like this:

    ```
    [
        [col1, col2],
        [],
        [col1]
        [col1, col2, col3],
        None  # not sure about this one, but we catch it
    ]
    ```

    Arguments:
    ----------
    jagged_array : List[List|None]
        A jagged array

    Returns:
    --------
    Iterator : complete rows for this array (filled up with None)
    """
    NUM_COLUMNS = max([len(row) for row in jagged_array])
    EMPTY_ROW = [None] * NUM_COLUMNS

    for row in jagged_array:
        if row:
            pass #value else None
        else:
            yield EMPTY_ROW
